@@ -6,6 +6,8 @@
 #' specification are given under 'Details'.
 #'@param data A data frame or matrix containing the model response variable
 #' and covariates required by the \code{formula}.
+#' @param na.action A function which indicates what should happen when the 
+#' data contain 'NA's. The default is 'na.omit'.
 #' @param der Number which determines any inference process. 
 #' By default \code{der} is \code{NULL}. If this term is \code{0}, 
 #' the testing procedures is applied for the estimate. If it is \code{1} or
@@ -119,6 +121,9 @@
 #' data(barnacle)
 #' localtest(DW ~ RC : F, data = barnacle, der = 1, seed = 130853, nboot = 100)
 #' 
+#' # localtest(height ~ s(age, by = sex), data = children, seed = 130853, 
+#' # der = 1, smooth = "splines") 
+#' 
 #' @useDynLib npregfast localtest_
 #' @importFrom stats na.omit runif
 #' @importFrom mgcv interpret.gam gam predict.gam
@@ -131,10 +136,12 @@
 
 
 
-localtest <- function(formula, data = data, der, smooth = "kernel", weights = NULL, 
-                      nboot = 500, h0 = -1.0, h = -1.0, nh = 30, kernel = "epanech", 
-                      p = 3, kbin = 100, rankl = NULL, ranku = NULL, seed = NULL,
-                      cluster = TRUE, ncores = NULL, ...) {
+localtest <- function(formula, data = data, na.action = "na.omit",
+                      der, smooth = "kernel", weights = NULL, 
+                      nboot = 500, h0 = -1.0, h = -1.0, nh = 30, 
+                      kernel = "epanech", p = 3, kbin = 100, rankl = NULL, 
+                      ranku = NULL, seed = NULL, cluster = TRUE, 
+                      ncores = NULL, ...) {
   
   if(kernel == "gaussian")  kernel <- 3
   if(kernel == "epanech")   kernel <- 1
@@ -183,6 +190,8 @@ localtest <- function(formula, data = data, der, smooth = "kernel", weights = NU
   
   
   
+  
+  
   if (smooth != "splines") {
     
     ffr <- interpret.frfastformula(formula, method = "frfast")
@@ -196,29 +205,52 @@ localtest <- function(formula, data = data, der, smooth = "kernel", weights = NU
     namef <- aux[2]
     if (length(aux) == 1) {f <- NULL}else{f <- data[ ,namef]}
     newdata <- data
-    data <- na.omit(data[ ,c(ffr$response, varnames)])
-    #newdata <- na.omit(newdata[ ,varnames])
-    n <- nrow(data)
+    data <- data[ ,c(ffr$response, varnames)]
     
-  }else{
-    ffr <- interpret.gam(formula)
-    varnames <- ffr$pred.names[1]
-    if (":" %in% unlist(strsplit(ffr$fake.names,split = ""))) {
-      stop("Argument \"formula\" is wrong specified, see details of
-             model specification in 'Details' of the frfast help." )
-    }
     
-    namef <- ffr$pred.names[2]
-    if (length(ffr$pred.names) == 1) {f <- NULL}else{f <- data[ ,namef]}
-    newdata <- data
-    if (length(ffr$pred.names) == 1) {
-      data <- na.omit(data[ ,c(ffr$response, varnames)])
+    if (na.action == "na.omit"){ # ver la f
+      data <- na.omit(data)
     }else{
-      data <- na.omit(data[ ,c(ffr$response, varnames, namef)])
+      stop("The actual version of the package only supports 'na.omit' (observations are removed 
+           if they contain any missing values)")
     }
     #newdata <- na.omit(newdata[ ,varnames])
     n <- nrow(data)
-  }
+    
+    }else{
+      ffr <- interpret.gam(formula)
+      varnames <- ffr$pred.names[1]
+      if (":" %in% unlist(strsplit(ffr$fake.names,split = ""))) {
+        stop("Argument \"formula\" is wrong specified, see details of
+             model specification in 'Details' of the frfast help." )
+      }
+      if (length(ffr$smooth.spec) == 0) {
+        warning("Argument \"formula\" could be wrong specified without an 's', see details of
+                model specification in 'Details' of the frfast help." )
+      }
+      
+      namef <- ffr$pred.names[2]
+      if (length(ffr$pred.names) == 1) {f <- NULL}else{f <- data[ ,namef]}
+      newdata <- data
+      
+      if (length(ffr$pred.names) == 1) {
+        data <- data[ ,c(ffr$response, varnames)]
+      }else{
+        data <- data[ ,c(ffr$response, varnames, namef)]
+      }
+      
+      if (na.action == "na.omit"){
+        data <- na.omit(data)
+      }else{
+        stop("The actual version of the package only supports 'na.omit' (observations are removed 
+             if they contain any missing values)")
+      }
+      
+      n <- nrow(data)
+      }
+  
+  
+  
   
   
   if (is.null(f)) f <- rep(1, n)
@@ -293,8 +325,9 @@ localtest <- function(formula, data = data, der, smooth = "kernel", weights = NU
                           D = as.double(rep(-1.0,1)),
                           Ci = as.double(rep(-1.0,1)),
                           Cs = as.double(rep(-1.0,1)),
-                          seed = as.integer(seed),
-                          umatrix = as.double(umatrix)
+                         # seed = as.integer(seed),
+                          umatrix = as.double(umatrix),
+                          PACKAGE = "npregfast"
     )
     
     
@@ -310,7 +343,7 @@ localtest <- function(formula, data = data, der, smooth = "kernel", weights = NU
     
   }else{
     
-    mainfun_localtest <- function(formula, data, weights){
+    mainfun_localtest <- function(formula, data, weights, ...){
       
       # grid
       xgrid <- seq(min(data[ ,varnames]), max(data[ ,varnames]), length.out = kbin)
@@ -379,7 +412,7 @@ localtest <- function(formula, data = data, der, smooth = "kernel", weights = NU
     
     
     
-    d <- mainfun_localtest(formula, data = data, weights = weights)
+    d <- mainfun_localtest(formula, data = data, weights = weights, ...)
     
     # bootstrap
     m <- gam(formula, weights = weights, data = data.frame(data, weights), ...)
